#
# spec file for package FreeCAD
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


#%%define _prefix /opt/FreeCAD

Name:           FreeCAD
Summary:        FreeCAD is a general purpose 3D CAD modeler
License:        GPL-2.0 and LGPL-2.0
Group:          Productivity/Graphics/3D Editors
Version:        0.13.480f28
Release:        1.15
Url:            http://juergen-riegel.net/FreeCAD/Docu/index.php?title=Main_Page
Source0:        freecad-%version.tar.bz2
Source1:        FreeCAD-rpmlintrc
Source2:        FreeCAD.conf
Patch:          susepatches.diff
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  Coin-devel
BuildRequires:  OpenCASCADE-devel
BuildRequires:  SoQt-devel
BuildRequires:  boost-devel >= 1.34.0
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  freeglut-devel
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
BuildRequires:  glibc-devel
BuildRequires:  libQtWebKit-devel
BuildRequires:  libXerces-c-devel
BuildRequires:  libeigen3-devel
BuildRequires:  libjasper-devel
BuildRequires:  libqt4
BuildRequires:  libqt4-devel
BuildRequires:  libraw1394-devel
BuildRequires:  libzipios0-devel
BuildRequires:  make
BuildRequires:  opencv-devel
BuildRequires:  python-cxx-devel
BuildRequires:  python-devel
BuildRequires:  python-xml
BuildRequires:  swig
BuildRequires:  unzip
BuildRequires:  update-desktop-files
BuildRequires:  cmake
%if %suse_version >= 1140
BuildRequires:  libdc1394-devel
%else
BuildRequires:  libdc1394_control12-devel
%endif
#BuildRequires:  -post-build-checks
Requires:       python-cxx
Requires:       python-pivy

%description
FreeCAD will be a general purpose 3D CAD modeler.
The development will be completely Open Source.
As with many modern 3D CAD modelers it will
have a 2D component in order to extract design detail
from the 3D model to create 2D production drawings,
although 2D (e.g. AutoCAD LT) is not the focus,
neither are animation and organic shapes
(e.g. Maya, 3D StudioMAX and Cinema 4D).

%package devel
Summary:        Devel package for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
FreeCAD will be a general purpose 3D CAD modeler.
The development will be completely Open Source.
As with many modern 3D CAD modelers it will
have a 2D component in order to extract design detail
from the 3D model to create 2D production drawings,
although 2D (e.g. AutoCAD LT) is not the focus,
neither are animation and organic shapes
(e.g. Maya, 3D StudioMAX and Cinema 4D).



%prep
%setup -q -n freecad-%{version}
%if 0%{?suse_version} == 1140
%patch -p1
%endif

#Fix eol
for f in ChangeLog.txt copying.lib README.Linux; do
  cp -p ${f} ${f}.eol
  sed -i 's/\r//' ${f}
  touch -r ${f}.eol ${f}
  rm ${f}.eol
done

%build
#	-DCMAKE_INSTALL_PREFIX=%%{_libexecdir}/freecad \
#	-DCMAKE_INSTALL_LIBDIR=%%{_libdir} \
#	-DCMAKE_INSTALL_DATADIR=%%{_datadir}/freecad \
#	-DCMAKE_INSTALL_INCLUDEDIR=%%{_includedir}/freecad \
#cmake . \
#	-DFREECAD_BUILD_DEBIAN=ON \
#	-DCMAKE_INSTALL_DOCDIR=%%{_defaultdocdir}/freecad

cmake -DCMAKE_INSTALL_PREFIX=%{_libdir}/FreeCAD \
      -DCMAKE_INSTALL_BINDIR=%{_bindir} \
      -DCMAKE_INSTALL_DOCDIR==%{_defaultdocdir} \
      -DCMAKE_INSTALL_LIBDIR=%{_libdir} \
      -DCMAKE_INSTALL_DATADIR=%{_datadir}/FreeCAD \
      -DCMAKE_INSTALL_DOCDIR=%{_defaultdocdir}/FreeCAD \
      -DCMAKE_INSTALL_INCLUDEDIR=%{_includedir}/FreeCAD \
      -DCMAKE_BUILD_TYPE=Release \
      -DCMAKE_SKIP_RPATH=1 

%__make VERBOSE=1 %{?_smp_mflags}



%install
make install DESTDIR=%{buildroot}

#%%__mkdir -p %%{buildroot}/usr/bin
#%%__ln_s %%{_bindir}/%%{name} %%{buildroot}/usr/bin/%%{name}

#%%__ln_s %%{_bindir}/%%{name}Cmd %%{buildroot}/usr/bin/%%{name}Cmd

#fixes desktop file check...
mkdir -p %buildroot/usr/share/pixmaps
mv %{buildroot}/%_datadir/FreeCAD/freecad.xpm %{buildroot}/%{_datadir}/pixmaps/freecad.xpm
%suse_update_desktop_file -c %{name} "%{name}" "%{name} is a general purpose 3D CAD modeler" %{name} "freecad.xpm" Graphics 3DGraphics

#mkdir -p %%buildroot/etc/ld.so.conf.d/
#cp %%SOURCE2 %%buildroot/etc/ld.so.conf.d/


%fdupes -s %{buildroot}

%clean
rm -fr %buildroot

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc ChangeLog.txt copying.lib README.Linux
%{_libdir}/FreeCAD
%exclude %{_libdir}/FreeCAD/include
%{_datadir}/FreeCAD
%{_datadir}/pixmaps/freecad.xpm
%{_datadir}/applications/%{name}.desktop
#%%config /etc/ld.so.conf.d/FreeCAD.conf

%files devel
%defattr(-,root,root)
%dir %{_libdir}/FreeCAD/include
%{_libdir}/FreeCAD/include

%changelog
* Sun May  8 2011 andrea@links2linux.de
- New upstream version 0.11.4446
* Fri Apr 22 2011 andrea@links2linux.de
- new upstream version 0.11.4422
- removed unsupported suse versions from spec file
- fixed build failure with suse 11.4 (boost too new)
* Fri Dec 10 2010 andrea@links2linux.de
- new upstream version 0.11.3729
* Thu Sep  2 2010 andrea@links2linux.de
- new upstream version 0.10.3247
* Tue Jan  5 2010 andrea@links2linux.de
- new upstream version 0.9.2646
* Tue Sep 29 2009 andrea@links2linux.de
- new upstream version
* Sat Apr  4 2009 Andrea Florio <andrea@links2linux.de>
- New upstream version 0.7.2008
* Sat Dec 20 2008 Andrea Florio <andrea@links2linux.de>
- New Upstream version 0.7.1779
* Mon Nov 24 2008 Andrea Florio <andrea@links2linux.de>
- New Upstream version 0.7.1672
* Mon Oct 13 2008 Andrea Florio <andrea@links2linux.de>
- New Upstream version 0.7.1658
* Tue Oct  7 2008 Andrea Florio <andrea@links2linux.de> - 0.pm.svn20081007
- built svn version that build with openCASCADE 6.3.0
* Sat Sep 27 2008 Andrea Florio <andrea@links2linux.de> - 0.7.1514
- new package
